#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://www.audiocoding.com/faad2.html
# last revised     : 13.09.2011

set -e -u -x

softname='faad2'
softversion='2.7'
packageversion='72.2'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.sourceforge.net/faac/$softname-$softversion.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
faad2: faad2 is an open source MPEG-4 and MPEG-2 AAC decoder
faad2:
faad2: FAAD2 is an open source MPEG-4 and MPEG-2 AAC decoder, it is licensed
faad2: under the GPLv2 license.
faad2: Features:
faad2: * Portable
faad2: * Reasonably fast
faad2: * LC, Main, LTP, SBR, PS support
faad2: * DRM support through DreaM
faad2: 
faad2:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

	patch -p1 < ../incorrect_pointer_size.patch
	patch -p1 < ../bpa-stdin.patch
	patch -p1 < ../path_max.patch

    ./configure \
      --prefix=/usr \
      --mandir=/usr/man \
      --infodir=/usr/info \
      --sysconfdir=/etc \
      --without-drm \
      --build=$arch-slackware-linux

    make
    make install DESTDIR=$dest

# Additionally, install libmp4ff
install -m 755 common/mp4ff/libmp4ff.a $dest/usr/lib
install -D common/mp4ff/mp4ff.h $dest/usr/include/mp4ff.h

# add 'default' files
    cp -a \
      AUTHORS COPYING ChangeLog NEWS README* TODO \
      $dest/usr/doc/$softname-$softversion
  
# Compress Man & Info Pages
gzip -9 $dest/usr/man/man?/*

# Strip
( cd $dest
find $dest | xargs -r file | grep "executable\|shared object" | grep ELF |\
	cut -f 1 -d : | xargs -r strip --strip-unneeded
find $dest | xargs -r file | grep "current ar archive" |\
	cut -f 1 -d : | xargs -r strip -g
)

# Buildscript
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
cp $buildir/*.patch $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# md5sum signature
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/ap/faad2/source/build-faad2.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
